==> haskell-concurrent-supply-0.1.8-252-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concurrent-supply.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concurrent-supply
version:              0.1.8
visibility:           public
id:                   concurrent-supply-0.1.8-ER49MitFOQr5ZcLNdDw7Xe
key:                  concurrent-supply-0.1.8-ER49MitFOQr5ZcLNdDw7Xe
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/concurrent-supply/
synopsis:             A fast concurrent unique identifier supply with a pure API
description:
    A fast supply of concurrent unique identifiers suitable for use
    within a single process. Once the initial '\''Supply'\'' has been initialized,
    the remainder of the API is pure. See "Control.Concurrent.Supply" for
    details.

category:             Concurrency, Parallelism
abi:                  613d3094f7049ef55a1c96f6e283e4cf
exposed:              True
exposed-modules:      Control.Concurrent.Supply
import-dirs:          /usr/lib/ghc-9.4.8/site-local/concurrent-supply-0.1.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/concurrent-supply-0.1.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/concurrent-supply-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concurrent-supply
hs-libraries:         HSconcurrent-supply-0.1.8-ER49MitFOQr5ZcLNdDw7Xe
depends:
    base-4.17.2.1 ghc-prim-0.9.1
    hashable-1.4.4.0-4IkOt4KzeSSA3Xc4u5PLaT

haddock-interfaces:
    /usr/share/doc/haskell-concurrent-supply/html/concurrent-supply.haddock

haddock-html:         /usr/share/doc/haskell-concurrent-supply/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concurrent-supply-0.1.8-253-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concurrent-supply.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concurrent-supply
version:              0.1.8
visibility:           public
id:                   concurrent-supply-0.1.8-Jfy8ajQFUmEEybq7LbQaaf
key:                  concurrent-supply-0.1.8-Jfy8ajQFUmEEybq7LbQaaf
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/concurrent-supply/
synopsis:             A fast concurrent unique identifier supply with a pure API
description:
    A fast supply of concurrent unique identifiers suitable for use
    within a single process. Once the initial '\''Supply'\'' has been initialized,
    the remainder of the API is pure. See "Control.Concurrent.Supply" for
    details.

category:             Concurrency, Parallelism
abi:                  bb5e6bf022723d02e464abb0710a8cf3
exposed:              True
exposed-modules:      Control.Concurrent.Supply
import-dirs:          /usr/lib/ghc-9.4.8/site-local/concurrent-supply-0.1.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/concurrent-supply-0.1.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/concurrent-supply-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concurrent-supply
hs-libraries:         HSconcurrent-supply-0.1.8-Jfy8ajQFUmEEybq7LbQaaf
depends:
    base-4.17.2.1 ghc-prim-0.9.1
    hashable-1.4.4.0-CTf4tWLvOCwE4B8hp3PoEK

haddock-interfaces:
    /usr/share/doc/haskell-concurrent-supply/html/concurrent-supply.haddock

haddock-html:         /usr/share/doc/haskell-concurrent-supply/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
